use crate::components;
use crate::util::surrealdb::{client::sort_participants, schemas};
use leptos::*;
use leptos_router::*;

/// Renders the home page of your application.
#[component]
pub fn HomePage() -> impl IntoView {
    let participants_context = use_context::<schemas::ParticipantsContext>().unwrap();

    let name = create_rw_signal("".to_string());

    let participants_sorted =
        create_memo(move |_| sort_participants(participants_context.get(), name.get()));

    view! {
        <div class="actions-container">
            <A href="/add-participant">"Deelnemer toevoegen"</A>
            <A href="/add-time">"Tijd toevoegen"</A>
            <A href="/groups">"Group view"</A>
        </div>
        <input type="search"
            class="participants-search"
            placeholder="Search"
            autocomplete="off"
            autofocus=true
            on:input=move |ev| {
                name.set(event_target_value(&ev));
            }
            prop:value=name
        />
        <components::participants::Participants participants=participants_sorted.into() />
    }
}
